%bcond_without reconf

Name: R
Version: 3.6.3
Release: 1
License: GPL-2.0-only
Summary: R Programming Language
Url: https://www.r-project.org

Source0: https://mirror.las.iastate.edu/CRAN/src/base/R-3/R-%{version}.tar.gz

Patch0: R-fix-sed-for-libR-pkgconfig.patch
Patch1: R-dynload-svr4-style-shared-libraries.patch
Patch2: R-proper-configure-flags.patch
Patch3: R-utils-missing-lzma.patch

BuildRequires: autoconf
BuildRequires: automake
BuildRequires: blas-devel
BuildRequires: bzip2-devel
BuildRequires: cairo-devel
BuildRequires: curl-devel
BuildRequires: icu-devel
BuildRequires: lapack-devel
BuildRequires: libffi-devel
# >= 1.14-4 needed for headers in pkgs/include
BuildRequires: libiconv-devel >= 1.14-4
BuildRequires: libintl-devel
BuildRequires: libjpeg-turbo-devel
BuildRequires: libpng-devel
BuildRequires: libtiff-devel
BuildRequires: libtool
BuildRequires: libutil-devel
BuildRequires: libX11-devel
BuildRequires: libXt-devel
BuildRequires: pango-devel
# Note: Seems pcre is *required* in R 3, even when building with pcre2
# We can build with pcre2 only when we upgrade to R 4
BuildRequires: pcre-devel
BuildRequires: pcre2-devel
BuildRequires: readline-devel
BuildRequires: tcl-devel
BuildRequires: tk-devel
BuildRequires: unzip
BuildRequires: xz-devel
BuildRequires: zlib-devel
BuildRequires: zip

BuildRequires: gcc-gfortran
BuildRequires: bison
BuildRequires: coreutils-gnu
BuildRequires: pkg-config

# TODO: Why is this required by R?
Requires: coreutils-gnu

%description
R is a programming language and free software environment for statistical
computing and graphics supported by the R Foundation for Statistical Computing.

The R language is widely used among statisticians and data miners for
developing statistical software and data analysis.

%package devel
Requires: %{name} = %{version}-%{release}
Group: Development/Libraries
Summary: Files needed for building R extensions

%description devel
The R-devel package contains the files needed for building R extensions.

%prep
%setup -q

%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

%build

%if ! %{with reconf}
%define _host powerpc-ibm-aix6
%else
%define _host powerpc64-ibm-os400

# TODO: Shouldn't this already be done by -f flag?
rm m4/libtool.m4 \
   'm4/lt~obsolete.m4' \
   m4/ltoptions.m4 \
   m4/ltsugar.m4 \
   m4/ltversion.m4

autoreconf -fi -I m4
%endif

%configure \
    ac_cv_have_decl_utimensat=no \
    CPPFLAGS='-pthread' \
    LDFLAGS="-pthread -Wl,-brtl -Wl,-bbigtoc -Wl,-bnoexpall -Wl,-blibpath:%{_libdir}:%{_libdir}/R/lib:/QOpenSys/usr/lib" \
    --enable-threads \
    --enable-R-shlib \
    --enable-static=no \
    --disable-static \
    --enable-shared=yes \
    --with-readline \
    --with-blas \
    --with-lapack \
    --with-ICU \
    --with-cairo \
    --with-libpng \
    --with-jpeglib \
    --with-libtiff \
    --with-x \
    --with-tcltk \
    --with-recommended-packages \
    --with-internal-tzcode
    
echo cleaning now 
make clean
echo building now
%make_build

touch doc/NEWS.pdf

%install

%make_install

rm %{buildroot}%{_libdir}/charset.alias || :

%files
%defattr(-, qsys, *none)
%{_bindir}/*
%{_libdir}/R
%{_mandir}/man1/*

%exclude %{_libdir}/R/include
%exclude %{_libdir}/R/SVN-REVISION

%files devel
%defattr(-, qsys, *none)
%{_libdir}/R/include/*
%{_libdir}/pkgconfig/*.pc



%changelog
* Mon Apr 26 2021 Kevin Adler <kadler@us.ibm.com> - 3.6.3
- Build with ICU and Cairo

* Tue Apr 06 2021 Kevin Adler <kadler@us.ibm.com> - 3.6.3
- Bump to 3.6.3

* Wed Mar 03 2021 Kevin Adler <kadler@us.ibm.com> - 3.5.1
- Build with libtiff and X.org X11
- Get rid of unnecessary compile flags
- Enable -pthread always
- Patch configure to understand OS400 and use proper PIC and SHLIB_LDFLAGS
- Patch util.so build rules to link with lzma
- Add build reqs for zip and unzip

* Fri Nov 20 2020 Abdirahim Musse <abdirahim.musse@ibm.com> - 3.5.1
- Allow dyn.load to work with svr4-style shared libraries

* Wed Nov 11 2020 Naveen Ram <naveen.ram@ibm.com> - 3.5.1
- Build R with PCRE2 instead of PCRE

* Thu Sep 17 2020 Naveen Ram <naveen.ram@ibm.com> - 3.5.1
- Add blas-devel to BuildRequires to link libblas

* Mon Jan 27 2020 Kevin Adler <kadler@us.ibm.com> - 3.5.1
- Fix sed delimiters used for generating libR.pc

* Tue Dec 10 2019 Abdirahim Musse <abdirahim.musse@ibm.com>
- Prevent linking to utimensat

* Fri Jul 05 2019 Jesse Gorzinski <jgorzins@us.ibm.com> 3.5.1
- Add TCL/TK support

* Mon Jun 3 2019 - Jesse R. Gorzinski <jgorzins@us.ibm.com>
- R initial spec file
